[LyX/master] Allow counter insets in pass thru

Juergen Spitzmueller spitz at lyx.org
Thu May 6 12:34:58 UTC 2021


commit 67762aaf084d1287f3447c19208f0ee8c41ddd63
Author: Juergen Spitzmueller <spitz at lyx.org>
Date:   Thu May 6 14:44:42 2021 +0200

    Allow counter insets in pass thru
---
 src/insets/InsetText.cpp |    4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)

diff --git a/src/insets/InsetText.cpp b/src/insets/InsetText.cpp
index 1867e8c..819c87d 100644
--- a/src/insets/InsetText.cpp
+++ b/src/insets/InsetText.cpp
@@ -945,9 +945,11 @@ bool InsetText::hasCProtectContent(bool fragile) const
 bool InsetText::insetAllowed(InsetCode code) const
 {
 	switch (code) {
 	// Arguments and (plain) quotes are also allowed in PassThru insets
 	case ARG_CODE:
 	case QUOTE_CODE:
+	case COUNTER_CODE:
 		return true;
 	default:
 		return !isPassThru();
@@ -945,9 +945,11 @@ bool InsetText::hasCProtectContent(bool fragile) const
 {
 	switch (code) {
-	// Arguments and (plain) quotes are also allowed in PassThru insets
+	// Arguments, (plain) quotes and counter insets 
+	// are also allowed in PassThru insets
 	case ARG_CODE:
 	case QUOTE_CODE:


More information about the lyx-cvs mailing list